import { Story, Canvas, Meta, Description } from "@storybook/addon-docs/blocks";
import { html } from "lit-html";
import { withKnobs, select } from "@storybook/addon-knobs";
import blindCopy from "../helpers/blindCopy";
import CATEGORIES from "../categories";
import readme from "../../dist/docs/components/scroll-to-top-button/readme.md";

<Meta title={CATEGORIES.COMPONENTS + "ScrollToTopButton"} />

# ScrollToTopButton

This is a simple component that scrolls to the top of the page.

<Canvas>
    <Story
        name="default"
        parameters={{ jest: ["scroll-to-top-button.e2e.ts"] }}
    >
        {html` <ui-scroll-to-top-button></ui-scroll-to-top-button> `}
    </Story>
</Canvas>

## Example with text

<Canvas
    mdxSource={`
    <ui-scroll-to-top-button></ui-scroll-to-top-button>
`}
>
    <Story name="Example with text">
        {html`
            <div style="max-width: 800px;margin:0 auto">
                ${blindCopy}
                <ui-scroll-to-top-button></ui-scroll-to-top-button>
            </div>
        `}
    </Story>
</Canvas>

## Example of alignment (right)

<Canvas
    mdxSource={`
    <div class="ui-u-text-align--right">
        <ui-scroll-to-top-button></ui-scroll-to-top-button>
    </div>
`}
>
    <Story name="Alignment" parameters={{ decorators: [withKnobs] }}>
        {html`
            <div style="max-width: 800px;margin:0 auto">
                ${blindCopy}
                <div
                    class="${select(
                        "Alignment",
                        {
                            Center: "ui-u-text-align--center",
                            Left: "ui-u-text-align--left",
                            Right: "ui-u-text-align--right",
                        },
                        "ui-u-text-align--right"
                    )}"
                >
                    <ui-scroll-to-top-button></ui-scroll-to-top-button>
                </div>
            </div>
        `}
    </Story>
</Canvas>

# Developer Documentation

<Description markdown={readme} />
